==> jc-1.4.0.tar.gz: gnu/java/nio/SocketChannelSelectionKey.h <==
// public final class gnu.java.nio.SocketChannelSelectionKey

// class file dependencies
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 3e93f4935b40b88f gnu_java_nio_SocketChannelSelectionKey
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header gnu_java_nio_SelectionKeyImpl

#include "gnu/java/nio/SelectionKeyImpl.h"

#ifndef _JC_gnu_java_nio_SocketChannelSelectionKey_H_
#define _JC_gnu_java_nio_SocketChannelSelectionKey_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs	_jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs	_jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$refs	_jc_gnu_java_nio_SocketChannelSelectionKey$refs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs	_jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$object	_jc_gnu_java_nio_SocketChannelSelectionKey$object;

typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vmethods	_jc_gnu_java_nio_SocketChannelSelectionKey$vmethods;
typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtable	_jc_gnu_java_nio_SocketChannelSelectionKey$vtable;
typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtype	_jc_gnu_java_nio_SocketChannelSelectionKey$vtype;

// Constructors
extern void _jc_gnu_java_nio_SocketChannelSelectionKey$method$_init$57e773c5fdc3e0ed(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *, struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *);

// Virtual methods
extern jint _jc_gnu_java_nio_SocketChannelSelectionKey$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SocketChannelSelectionKey$method_info$getNativeFD$4ed008ed25fb0a89;

// Virtual methods structure
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *);
};

// Vtable
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vmethods	gnu_java_nio_SocketChannelSelectionKey;
};

// Vtype
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$refs {
    _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs	gnu_java_nio_SocketChannelSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
    _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs	gnu_java_nio_SocketChannelSelectionKey;
};

// Object instance structure
struct _jc_gnu_java_nio_SocketChannelSelectionKey$object {
	_jc_gnu_java_nio_SocketChannelSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vtype	*vtype;
	_jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SocketChannelSelectionKey$vtype _jc_gnu_java_nio_SocketChannelSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SocketChannelSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SocketChannelSelectionKey$class_object;

#endif	/* _JC_gnu_java_nio_SocketChannelSelectionKey_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/SocketChannelSelectionKey.h <==
// public final class gnu.java.nio.SocketChannelSelectionKey

// class file dependencies
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 3e93f4935b40b88f gnu_java_nio_SocketChannelSelectionKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header gnu_java_nio_SelectionKeyImpl

#include "gnu/java/nio/SelectionKeyImpl.h"

#ifndef _JC_gnu_java_nio_SocketChannelSelectionKey_H_
#define _JC_gnu_java_nio_SocketChannelSelectionKey_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs	_jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs	_jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$refs	_jc_gnu_java_nio_SocketChannelSelectionKey$refs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs	_jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs;
typedef struct _jc_gnu_java_nio_SocketChannelSelectionKey$object	_jc_gnu_java_nio_SocketChannelSelectionKey$object;

typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vmethods	_jc_gnu_java_nio_SocketChannelSelectionKey$vmethods;
typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtable	_jc_gnu_java_nio_SocketChannelSelectionKey$vtable;
typedef const struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtype	_jc_gnu_java_nio_SocketChannelSelectionKey$vtype;

// Constructors
extern void _jc_gnu_java_nio_SocketChannelSelectionKey$method$_init$57e773c5fdc3e0ed(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *, struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_nio_SocketChannelSelectionKey$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SocketChannelSelectionKey$method_info$getNativeFD$4ed008ed25fb0a89;

// Virtual methods structure
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_SocketChannelSelectionKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vmethods	gnu_java_nio_SocketChannelSelectionKey;
};

// Vtype
struct _jc_gnu_java_nio_SocketChannelSelectionKey$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$refs {
    _jc_gnu_java_nio_SocketChannelSelectionKey$sub_refs	gnu_java_nio_SocketChannelSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
    _jc_gnu_java_nio_SocketChannelSelectionKey$sub_nonrefs	gnu_java_nio_SocketChannelSelectionKey;
};

// Object instance structure
struct _jc_gnu_java_nio_SocketChannelSelectionKey$object {
	_jc_gnu_java_nio_SocketChannelSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SocketChannelSelectionKey$vtype	*vtype;
	_jc_gnu_java_nio_SocketChannelSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SocketChannelSelectionKey$vtype _jc_gnu_java_nio_SocketChannelSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SocketChannelSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SocketChannelSelectionKey$class_object;

#endif	/* _JC_gnu_java_nio_SocketChannelSelectionKey_H_ */
